@@ -26,8 +26,6 @@ import macrometa_source_snowflake.sync_strategies.common as common
 import macrometa_source_snowflake.sync_strategies.full_table as full_table
 import macrometa_source_snowflake.sync_strategies.incremental as incremental
 from macrometa_source_snowflake.connection import SnowflakeConnection
-# TODO: Work on sample_data
-from macrometa_source_snowflake.sync_strategies.sample_data import fetch_samples
 
 LOGGER = singer.get_logger('macrometa_source_snowflake')
 
@@ -407,7 +405,7 @@ def write_schema_message(catalog_entry, bookmark_properties=None):
     ))
 
 
-def do_sync_incremental(snowflake_conn, catalog_entry, state, columns):
+def do_sync_incremental(snowflake_conn, catalog_entry, state, columns, replication_method):
     LOGGER.info('Stream %s is using incremental replication',
                 catalog_entry.stream)
 
@@ -421,12 +419,13 @@ def do_sync_incremental(snowflake_conn, catalog_entry, state, columns):
     write_schema_message(catalog_entry=catalog_entry,
                          bookmark_properties=[replication_key])
 
-    incremental.sync_table(snowflake_conn, catalog_entry, state, columns)
+    incremental.sync_table(snowflake_conn, catalog_entry,
+                           state, columns, replication_method)
 
     singer.write_message(singer.StateMessage(value=copy.deepcopy(state)))
 
 
-def do_sync_full_table(snowflake_conn, catalog_entry, state, columns):
+def do_sync_full_table(snowflake_conn, catalog_entry, state, columns, replication_method):
     LOGGER.info('Stream %s is using full table replication',
                 catalog_entry.stream)
 
@@ -436,7 +435,7 @@ def do_sync_full_table(snowflake_conn, catalog_entry, state, columns):
         catalog_entry.tap_stream_id, state)
 
     full_table.sync_table(snowflake_conn, catalog_entry,
-                          state, columns, stream_version)
+                          state, columns, stream_version, replication_method)
 
     # Prefer initial_full_table_complete going forward
     singer.clear_bookmark(state, catalog_entry.tap_stream_id, 'version')
@@ -449,7 +448,7 @@ def do_sync_full_table(snowflake_conn, catalog_entry, state, columns):
     singer.write_message(singer.StateMessage(value=copy.deepcopy(state)))
 
 
-def sync_streams(snowflake_conn, catalog, state):
+def sync_streams(snowflake_conn, catalog, state, replication_method):
     for catalog_entry in catalog.streams:
         columns = list(catalog_entry.schema.properties.keys())
 
@@ -466,7 +465,8 @@ def sync_streams(snowflake_conn, catalog, state):
 
         md_map = metadata.to_map(catalog_entry.metadata)
 
-        replication_method = md_map.get((), {}).get('replication-method')
+        replication_method = md_map.get((), {}).get(
+            'replication-method', replication_method)
 
         database_name = common.get_database_name(catalog_entry)
         schema_name = common.get_schema_name(catalog_entry)
@@ -480,10 +480,10 @@ def sync_streams(snowflake_conn, catalog, state):
 
             if replication_method == 'INCREMENTAL':
                 do_sync_incremental(
-                    snowflake_conn, catalog_entry, state, columns)
+                    snowflake_conn, catalog_entry, state, columns, replication_method)
             elif replication_method == 'FULL_TABLE':
                 do_sync_full_table(
-                    snowflake_conn, catalog_entry, state, columns)
+                    snowflake_conn, catalog_entry, state, columns, replication_method)
             else:
                 raise Exception(
                     'Only INCREMENTAL and FULL TABLE replication methods are supported')
@@ -492,25 +492,27 @@ def sync_streams(snowflake_conn, catalog, state):
     singer.write_message(singer.StateMessage(value=copy.deepcopy(state)))
 
 
-def do_sync(snowflake_conn, config, catalog, state):
+def do_sync(snowflake_conn, config, catalog, state, replication_method):
     catalog = get_streams(snowflake_conn, catalog, config, state)
-    sync_streams(snowflake_conn, catalog, state)
+    sync_streams(snowflake_conn, catalog, state, replication_method)
 
 
 def main_impl():
     args = utils.parse_args(REQUIRED_CONFIG_KEYS)
 
     snowflake_conn = SnowflakeConnection(args.config)
-
+    replication_method = args.config.get('replication_method')
     if args.discover:
         do_discover(snowflake_conn, args.config)
     elif args.catalog:
         state = args.state or {}
-        do_sync(snowflake_conn, args.config, args.catalog, state)
+        do_sync(snowflake_conn, args.config,
+                args.catalog, state, replication_method)
     elif args.properties:
         catalog = Catalog.from_dict(args.properties)
         state = args.state or {}
-        do_sync(snowflake_conn, args.config, catalog, state)
+        do_sync(snowflake_conn, args.config,
+                catalog, state, replication_method)
     else:
         LOGGER.info('No properties were selected')
 
@@ -548,51 +550,20 @@ class SnowflakeSourceConnector(C8Connector):
         """
         config = self.get_config(integration)
         try:
-            # TODO: CHECK ABOUT do_discover() and do_discovery and make changes
             do_discover(config)
         except Exception as e:
             raise e
 
-    def samples(self, integration: dict) -> list[Sample]: # TODO: Need to add handling of reserved keys
+    # TODO: Need to add handling of reserved keys
+    def samples(self, integration: dict) -> list[Sample]:
         """Fetch sample data using the provided configurations."""
-        config = self.get_config(integration)
-        try:
-            streams = do_discover(config)
-            results = []
-            for stream in streams:
-                s_attribs = []
-                s_schema = stream['schema']
-                for k, v in s_schema['properties'].items():
-                    t = v['type'][-1]
-                    s_attribs.append(SchemaAttribute(
-                        k, self.get_attribute_type(t)))
-                schema = Schema(stream['stream'], s_attribs)
-                results.append(Sample(
-                    schema=schema,
-                    data=fetch_samples(config, stream)[:10])
-                )
-        except Exception as e:
-            raise e
-        return results
+        return []
 
-    def schemas(self, integration: dict) -> list[Schema]: # TODO: Need to add handling of reserved keys
+    # TODO: Need to add handling of reserved keys
+    def schemas(self, integration: dict) -> list[Schema]:
         """Get supported schemas using the given configurations."""
-        config = self.get_config(integration)
-        try:
-            streams = do_discover(config)
-            results = []
-            for stream in streams:
-                s_attribs = []
-                s_schema = stream['schema']
-                for k, v in s_schema['properties'].items():
-                    t = v['type'][-1]
-                    s_attribs.append(SchemaAttribute(
-                        k, self.get_attribute_type(t)))
-                results.append(Schema(stream['stream'], s_attribs))
-        except Exception as e:
-            raise e
-        return results
-    
+        return []
+
     def reserved_keys(self) -> list[str]:
         """List of reserved keys for the connector."""
         return []
@@ -631,20 +602,20 @@ class SnowflakeSourceConnector(C8Connector):
             ConfigProperty('tables', 'Tables', ConfigAttributeType.STRING, True, False,
                            description='A comma separated list of the table names that you want to sync. The table names should be fully qualified including the db and schema name. For example, syncing table1 and table2 would look like `db.schema.table1,db.schema.table2`',
                            placeholder_value='my_table'),
-            ConfigProperty('default_replication_method', 'Default Replication Method',
+            ConfigProperty('replication_method', 'Replication Method',
                            ConfigAttributeType.STRING, True, False,
                            description='Choose from INCREMENTAL, FULL_TABLE',
                            default_value='FULL_TABLE'),
             ConfigProperty('role', 'Role',
                            ConfigAttributeType.STRING, False, False,
                            description='Snowflake role to use',
-                           default_value=None),
+                           placeholder_value='my_role'),
             ConfigProperty('private_key_path', 'Private Key Path', ConfigAttributeType.STRING, False, False,
                            description='A path to your private key used for authenticating using Key Pair authentication instead of user/pass',
-                           default_value=None),
+                           placeholder_value='private_key_path'),
             ConfigProperty('private_key_passphrase', 'Private Key Passphrase', ConfigAttributeType.STRING, False, False,
                            description='The private key passphrase used for authenticating using Key Pair authentication instead of user/pass',
-                           default_value=None),
+                           placeholder_value='private_key_passphrase'),
             ConfigProperty('insecure_mode', 'Insecure Mode', ConfigAttributeType.BOOLEAN, False, False,
                            description='Use insecure mode to avoid "Failed to get OCSP response" warnings',
                            default_value=False)
@@ -672,9 +643,9 @@ class SnowflakeSourceConnector(C8Connector):
                 # TODO: Check if this is necessery
                 'tap_id': integration.get('tap_id'),
 
-                'role': integration.get('role', None),
-                'private_key_path': integration.get('private_key_path', None),
-                'private_key_passphrase': integration.get('private_key_passphrase', None),
+                'role': integration.get('role'),
+                'private_key_path': integration.get('private_key_path'),
+                'private_key_passphrase': integration.get('private_key_passphrase'),
                 'insecure_mode': integration.get('insecure_mode', False),
             }
         except KeyError as e:
